{% extends "waliki/detail.html" %} {% block container %}
{% block page_tools %} Back to page Edit {% endblock page_tools %}
{% block title %}

### History: /{{ page.slug }}

{% endblock title %}
{% block content %} {% csrf_token %}

{% for version in history %}
| {{ version.commit }} | {{ version.author }} | {{ version.date_relative }} | {{ version.message }} |
{% endfor %}

{% if history|length > 10 %}
Back to top
{% endif %}
{% endblock content %} {% endblock container %} {% block extra_script %}
{% endblock %}